Index: pykota/trunk/po/en/pykota.po
===================================================================
--- pykota/trunk/po/en/pykota.po (revision 1628)
+++ pykota/trunk/po/en/pykota.po (revision 1646)
@@ -89,5 +89,5 @@
 
 #, python-format
-msgid "Invalid poor man's treshold %s"
+msgid "Invalid poor man's threshold %s"
 msgstr ""
 
Index: pykota/trunk/po/br/pykota.po
===================================================================
--- pykota/trunk/po/br/pykota.po (revision 1628)
+++ pykota/trunk/po/br/pykota.po (revision 1646)
@@ -86,5 +86,5 @@
 
 #, python-format
-msgid "Invalid poor man's treshold %s"
+msgid "Invalid poor man's threshold %s"
 msgstr "Valor 'poor man' %s inv�do"
 
Index: pykota/trunk/po/pt/pykota.po
===================================================================
--- pykota/trunk/po/pt/pykota.po (revision 1628)
+++ pykota/trunk/po/pt/pykota.po (revision 1646)
@@ -86,5 +86,5 @@
 
 #, python-format
-msgid "Invalid poor man's treshold %s"
+msgid "Invalid poor man's threshold %s"
 msgstr "Valor 'poor man' %s inv�do"
 
Index: pykota/trunk/po/es/pykota.po
===================================================================
--- pykota/trunk/po/es/pykota.po (revision 1628)
+++ pykota/trunk/po/es/pykota.po (revision 1646)
@@ -86,5 +86,5 @@
 
 #, python-format
-msgid "Invalid poor man's treshold %s"
+msgid "Invalid poor man's threshold %s"
 msgstr "Valor 'poor man' %s inv�do"
 
Index: pykota/trunk/po/fr/pykota.po
===================================================================
--- pykota/trunk/po/fr/pykota.po (revision 1628)
+++ pykota/trunk/po/fr/pykota.po (revision 1646)
@@ -90,5 +90,5 @@
 
 #, python-format
-msgid "Invalid poor man's treshold %s"
+msgid "Invalid poor man's threshold %s"
 msgstr "Valeur 'pauvre homme' %s invalide"
 
Index: pykota/trunk/po/pykota.pot
===================================================================
--- pykota/trunk/po/pykota.pot (revision 1628)
+++ pykota/trunk/po/pykota.pot (revision 1646)
@@ -89,5 +89,5 @@
 
 #, python-format
-msgid "Invalid poor man's treshold %s"
+msgid "Invalid poor man's threshold %s"
 msgstr ""
 
Index: pykota/trunk/po/sv/pykota.po
===================================================================
--- pykota/trunk/po/sv/pykota.po (revision 1632)
+++ pykota/trunk/po/sv/pykota.po (revision 1646)
@@ -89,6 +89,6 @@
 
 #, python-format
-msgid "Invalid poor man's treshold %s"
-msgstr "Ogiltigt fattigmansv�e (poor man's treshold) %s"
+msgid "Invalid poor man's threshold %s"
+msgstr "Ogiltigt fattigmansv�e (poor man's threshold) %s"
 
 msgid ""
Index: pykota/trunk/po/th/pykota.po
===================================================================
--- pykota/trunk/po/th/pykota.po (revision 1645)
+++ pykota/trunk/po/th/pykota.po (revision 1646)
@@ -89,6 +89,6 @@
 
 #, python-format
-msgid "Invalid poor man's treshold %s"
-msgstr "��poor man's treshold %s ��١��"
+msgid "Invalid poor man's threshold %s"
+msgstr "��poor man's threshold %s ��١��"
 
 msgid ""
Index: pykota/trunk/po/it/pykota.po
===================================================================
--- pykota/trunk/po/it/pykota.po (revision 1628)
+++ pykota/trunk/po/it/pykota.po (revision 1646)
@@ -92,6 +92,6 @@
 
 #, python-format
-msgid "Invalid poor man's treshold %s"
-msgstr "Poor man's treshold non valido %s"
+msgid "Invalid poor man's threshold %s"
+msgstr "Poor man's threshold non valido %s"
 
 msgid ""

Index: pykota/trunk/pykota/config.py
===================================================================
--- pykota/trunk/pykota/config.py (revision 1518)
+++ pykota/trunk/pykota/config.py (revision 1646)
@@ -22,4 +22,7 @@
 #
 # $Log$
+# Revision 1.50  2004/07/27 07:07:27  jalet
+# Typo : treshold ==> threshold
+#
 # Revision 1.49  2004/06/03 21:53:24  jalet
 # crashrecipient directive
@@ -458,5 +461,5 @@
             
     def getPoorMan(self) :    
         """Returns the poor man's treshold."""
         try :
             pm = self.getGlobalOption("poorman")
@@ -466,5 +469,5 @@
             return float(pm)
         except (TypeError, ValueError) :    
-            raise PyKotaConfigError, _("Invalid poor man's treshold %s") % pm
+            raise PyKotaConfigError, _("Invalid poor man's threshold %s") % pm
             
     def getPoorWarn(self) :    
@@ -458,5 +461,5 @@
             
     def getPoorMan(self) :    
-        """Returns the poor man's treshold."""
+        """Returns the poor man's threshold."""
         try :
             pm = self.getGlobalOption("poorman")